@@ -1,7 +1,7 @@
 /*
  * hpisel.c
  *
- * Author:  Andy Cress  arcress@users.sourceforge.net
+ * Author:  Andy Cress  arcress at users.sourceforge.net
  * Copyright (c) 2003-2005 Intel Corporation.
  *
  * 04/28/03 Andy Cress - created
@@ -465,18 +465,18 @@ decode_sensor_event(uchar sensor_type, uchar sensor_number,  ushort gen_id,
 			{ 
 			   case 0x00:  /* System firmware errors */
 				i = data2;
-				if (i > NFWERRS) i = NFWERRS;
+				if (i >= NFWERRS) i = NFWERRS - 1;
         		        pstr = fwerrs[i].msg;
 				break;
 			   case 0x01:  /* System firmware hang  */
 				i = data2;
-				if (i > NFWSTAT) i = NFWSTAT;
+				if (i >= NFWSTAT) i = NFWSTAT - 1;
 				sprintf(poststr,"hang, %s",fwstat[i].msg);
 				pstr = poststr;
 				break;
 			   case 0x02:  /* System firmware progress */
 				i = data2;
-				if (i > NFWSTAT) i = NFWSTAT;
+				if (i >= NFWSTAT) i = NFWSTAT - 1;
 				sprintf(poststr,"prog, %s",fwstat[i].msg);
 				pstr = poststr;
 				break;
