@@ -80,8 +80,13 @@
 #define PICMG_EKEY_AMC_MAX_DEVICE   15 /* 4 bits */
 
 /* Global data */
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil picmg";
+#else
+static char * progver   = "3.08";
 static char * progname  = "ipicmg";
-static char * progver   = "3.07";
+#endif
 static char   fdebug    = 0;
 static char   fset_mc   = 0;
 static uint8_t g_bus  = PUBLIC_BUS;
